@@ -12,6 +12,9 @@ if workspace:
 else:
     workspace = Path(".")
 
-p5core.install_helpers.installation_directory = workspace
 
-copy_file("README_user.md", "README.md")
+def install():
+    """Installation entry point."""
+    p5core.install_helpers.installation_directory = workspace
+
+    copy_file(Path("README_user.md"), Path("README.md"))
